summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAbdullah Sowayan <sowayan@users.noreply.github.com>2007-12-01 17:09:14 +0000
committerAbdullah Sowayan <sowayan@users.noreply.github.com>2007-12-01 17:09:14 +0000
commit690036a438454f2aef75b81ee253e5897d9040df (patch)
treebeaf69e96f77007aafa03e9f6e092498aae08389
parent2231979e0c29632f8047b28ca96fa9cc0f8a27e1 (diff)
downloadATCD-690036a438454f2aef75b81ee253e5897d9040df.tar.gz
Sat Dec 1 17:06:32 UTC 2007 Abdullah Sowayan <abdullah.sowayan@lmco.com>
-rw-r--r--ACE/ChangeLog9
-rwxr-xr-xACE/bin/fuzz.pl10
2 files changed, 14 insertions, 5 deletions
diff --git a/ACE/ChangeLog b/ACE/ChangeLog
index cd84b6a1b7e..73bb1e3a260 100644
--- a/ACE/ChangeLog
+++ b/ACE/ChangeLog
@@ -1,9 +1,16 @@
+Sat Dec 1 17:06:32 UTC 2007 Abdullah Sowayan <abdullah.sowayan@lmco.com>
+
+ * bin/fuzz.pl:
+ Fixed the checks of ACE_SYNCH_MUTEX and ACE_Thread_Mutex to exclude
+ checking for those key words in ACE. We only want to detect the usage
+ of those words in TAO and CIAO.
+
Fri Nov 30 23:59:41 UTC 2007 Abdullah Sowayan <abdullah.sowayan@lmco.com>
* bin/fuzz.pl:
Added the following checks:
-
+
check_for_ACE_SYNCH_MUTEX:
This test checks for the use of ACE_SYNCH_MUTEX in TAO/CIAO,
TAO_SYNCH_MUTEX should be used instead for consistency.
diff --git a/ACE/bin/fuzz.pl b/ACE/bin/fuzz.pl
index d797f0810c9..1350a1b3ad4 100755
--- a/ACE/bin/fuzz.pl
+++ b/ACE/bin/fuzz.pl
@@ -307,8 +307,9 @@ sub check_for_ACE_SYNCH_MUTEX ()
}
if ($disable == 0 and /ACE_SYNCH_MUTEX/) {
# It is okay to use ACE_SYNCH_MUTEX in ACE
- # so don't check the ACE directory
- if (($file =~ /ACE/)) {
+ # so don't check the ACE directory. The below
+ # will check it for TAO and CIAO.
+ if (($file !~ /.*TAO.*/)) {
next ITERATION;
}
@@ -344,8 +345,9 @@ sub check_for_ACE_Thread_Mutex ()
}
if ($disable == 0 and /ACE_Thread_Mutex/) {
# It is okay to use ACE_Thread_Mutex in ACE
- # so don't check the ACE directory
- if (($file =~ /ACE/)) {
+ # so don't check the ACE directory. The below
+ # will check it for TAO and CIAO.
+ if (($file !~ /.*TAO.*/)) {
next ITERATION;
}